var MessagePack = {
    // Returns key/value pairs of form field name and values.
    GetKeyValuePairs : function ()
    {
        var form = document.getElementsByTagName("form")[0];
        var formElements = form.elements;
        var numberOfFormElements = formElements.length;
        var keyValuePairs = {};
        
        for (var i=0; i < numberOfFormElements; ++i)
        {
            var element = formElements[i];
            keyValuePairs[element.name] = element.value; // this won't work with checkboxes/radio
        }
        
        return JSON.stringify(keyValuePairs);
    },
    
    
    // Returns a JSON string of the message pack contents and validation attributes
    GetValidationData : function () 
    {
        var form = document.getElementsByTagName("form")[0];
        var formElements = form.elements;
        var numberOfFormElements = formElements.length;
        var response = [];
        
        for (var i=0; i < numberOfFormElements; ++i)
        {
            var validationData = {};
            var element = formElements[i];
            
            validationData.name    = element.name;
            validationData.content = element.value; // this won't work with checkboxes/radio
            
            // Check for a 'required' class
            var className   = element.className.toLowerCase();
            var classArray  = className.split(" ");
            var requiredTag = classArray.indexOf("required");
            
            if (requiredTag != -1)
            {
                validationData.required = true;
            }
            
            // Look for attributes
            var attributes = element.attributes;
            for (var j=0; j < attributes.length; ++j)
            {
                var attribute = attributes[j];
                
                if (attribute.name == "minlength")
                {
                    validationData.minlength = attribute.value;
                }
                else if (attribute.name == "max-length")
                {
                    validationData.maxlength = attribute.value;
                }
                else if (attribute.name == "max-newlines")
                {
                    validationData.maxnewlines = attribute.value;
                }
            }
            
            // Add this element's validation data to the response object
            response.push(validationData);
        }
        
        return JSON.stringify(response);
    },
    
    
    _DisplayValueInFieldWithClass : function (fieldClass, value)
    {
        var field = document.getElementsByClassName(fieldClass)[0];
        if (field)
        {
            field.innerText = value;
            return 1;
        }
        return 0;
    },
    
    
    /** 
     * Displays the nickname (iOS only)
     * @param nickname (string) The nickname to set
     * @return 1 if the nickname field was detected, otherwise 0
     */
    DisplayNickname : function (nickname)
    {
        return MessagePack._DisplayValueInFieldWithClass("nickname", decodeURIComponent(nickname));
    },
    
    
    /**
     * Displays the time (iOS only)
     * @param time (string) The time to display
     * @return 1 if the time field was detected, otherwise 0
     */
    DisplayTime : function (time)
    {
        return MessagePack._DisplayValueInFieldWithClass("timestamp", decodeURIComponent(time));
    },
    
    
    /**
     * Displays the privileges (iOS only)
     * @param privileges (string) The privileges to display
     * @return 1 if the privilege field was detected, otherwise 0
     */
    DisplayPrivileges : function (privileges)
    {
        return MessagePack._DisplayValueInFieldWithClass("privileges", decodeURIComponent(privileges));
    },
    
    
    /**
     * Prints information to the Xcode console.
     * @param message (string) The message to print
     * @return void
     */
    log : function (message)
    {
        location.href = "ioslog://" + encodeURI(message);
    }
};